=== modified file '.bzrignore'
--- .bzrignore	2014-03-05 22:04:05 +0000
+++ .bzrignore	2015-05-15 16:54:14 +0000
@@ -7,3 +7,4 @@
 *.pyc
 exec.d
 build/charm-helpers
+revision

=== modified file 'Makefile'
--- Makefile	2015-05-15 14:11:31 +0000
+++ Makefile	2015-05-15 16:54:14 +0000
@@ -9,13 +9,9 @@
 
 build: test lint proof
 
-revision:
-	@test -f revision || echo 0 > revision
-
-proof: revision
+proof:
 	@echo Proofing charm...
-	@(charm proof $(PWD) || [ $$? -eq 100 ]) && echo OK
-	@test `cat revision` = 0 && rm revision
+	@charm proof
 
 .venv:
 	sudo apt-get install -y python-apt python-virtualenv python-jinja2
@@ -28,7 +24,7 @@
 
 lint:
 	@echo Checking for Python syntax...
-	@flake8 $(HOOKS_DIR) --ignore=E123 --exclude=$(HOOKS_DIR)/charmhelpers && echo OK
+	@flake8 $(HOOKS_DIR) --ignore=E123 --exclude=$(HOOKS_DIR)/charmhelpers
 
 sourcedeps: $(PWD)/config-manager.txt
 	@echo Updating source dependencies...

=== modified file 'hooks/hooks.py'
--- hooks/hooks.py	2015-05-15 13:49:35 +0000
+++ hooks/hooks.py	2015-05-15 16:54:14 +0000
@@ -11,7 +11,7 @@
 import yaml
 import pwd
 
-from itertools import izip, tee, groupby
+from itertools import izip, tee
 from operator import itemgetter
 
 from charmhelpers.core.host import pwgen, lsb_release
@@ -510,7 +510,7 @@
     result = target[:]
     for addition in additions:
         if addition not in result:
-           result.append(addition)
+            result.append(addition)
     return result
 
 
@@ -531,17 +531,9 @@
     # Merge all 'backends' and their contained "servers".
     if "backends" in old_service and "backends" in new_service:
         backends_by_name = {}
-        # Populate backends_by_name with backends from (old_)service.
-        for backend in service["backends"]:
-            backend_name = backend.get("backend_name")
-            if backend_name is None:
-                raise InvalidRelationDataError(
-                    "Each backend must have backend_name.")
-            backends_by_name.setdefault(backend_name, backend)
-
-        # Go through backends in new_service and add them to backends_by_name,
-        # merging 'servers' while at it.
-        for backend in new_service["backends"]:
+        # Go through backends in old and new configs and add them to
+        # backends_by_name, merging 'servers' while at it.
+        for backend in service["backends"] + new_service["backends"]:
             backend_name = backend.get("backend_name")
             if backend_name is None:
                 raise InvalidRelationDataError(

=== modified file 'hooks/tests/test_reverseproxy_hooks.py'
--- hooks/tests/test_reverseproxy_hooks.py	2015-05-15 13:49:35 +0000
+++ hooks/tests/test_reverseproxy_hooks.py	2015-05-15 14:31:41 +0000
@@ -505,6 +505,32 @@
         self.assertRaises(
             hooks.InvalidRelationDataError, hooks.merge_service, s1, s2)
 
+    def test_merge_service_no_old_backend(self):
+        """
+        If the old service config has no backends, the backends from the
+        new config is used..
+        """
+
+        s1 = {}
+        s2 = {'backends': [
+            {'backend_name': 'webapp',
+             'servers': [['webapp-1', '10.0.0.2', 8090, []]]},
+        ]}
+        self.assertEqual(s2, hooks.merge_service(s1, s2))
+
+    def test_merge_service_no_new_backend(self):
+        """
+        If the new service config has no backends, the backends from the
+        old config is used..
+        """
+
+        s1 = {'backends': [
+            {'backend_name': 'webapp',
+             'servers': [['webapp-1', '10.0.0.2', 8090, []]]},
+        ]}
+        s2 = {}
+        self.assertEqual(s1, hooks.merge_service(s1, s2))
+
     def test_merge_service_backend_name_matching(self):
         """Backends are merged by backend_name."""
 

=== modified file 'metadata.yaml'
--- metadata.yaml	2014-09-08 19:14:53 +0000
+++ metadata.yaml	2015-05-15 16:54:14 +0000
@@ -7,7 +7,7 @@
  cookies, load balancing, header addition, modification, deletion both ways. It
  has request blocking capabilities and provides interface to display server
  status.
-categories: ["cache-proxy"]
+tags: ["cache-proxy"]
 requires:
   reverseproxy:
     interface: http

=== removed file 'revision'
--- revision	2014-03-05 22:04:05 +0000
+++ revision	1970-01-01 00:00:00 +0000
@@ -1,1 +0,0 @@
-28

